==> gpe-applauncher-0.9.tar.bz2: gpe-applauncher-0.9/applications.h <==
/*
 * gpe-applauncher
 *
 * Application launcher for GPE Phone Edition.
 * 
 * (c) kernel concepts 2006, 2007
 * 
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
#ifndef _GPE_APPLAUNCHER_APPLICATIONS_H
#define _GPE_APPLAUNCHER_APPLICATIONS_H
    
void applications_create (GtkWidget *notebook);
void applications_update_background (GtkWidget *window);
void applications_update_itemsize (gint width);
void applications_update_theme (const gchar *themename);
void applications_update_item_layout (gint type);
void add_application (const gchar *filename);
void remove_application (const gchar *filename);
void set_super_folder_visible (void);
gboolean is_super_folder_visible (void);
int applications_start_service (const gchar *service_name, const gchar *method,
								const gchar* caller_service_name);
								
gboolean launch_application (const char *name, const char *executable, const char *argv,
                    		 gboolean single_instance, gboolean startup_notify,
							 const char *caller);
							 
enum 
  {
    LAYOUT_STACK = 0,
    LAYOUT_SIDE  = 1,
    LAYOUT_MAX   = 2
  }t_layout;

enum
  {
	ITEM_NORMAL  = 0,
	ITEM_FOCUSED = 1
  }t_item_status;
  

#define DEFAULT_APPS_PATH PREFIX "/share/applications" 

#endif

==> gpe-applauncher-0.10.tar.bz2: gpe-applauncher-0.10/applications.h <==
/*
 * gpe-applauncher
 *
 * Application launcher for GPE Phone Edition.
 * 
 * (c) kernel concepts 2006, 2007
 * 
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
#ifndef _GPE_APPLAUNCHER_APPLICATIONS_H
#define _GPE_APPLAUNCHER_APPLICATIONS_H
    
void applications_create (GtkWidget *notebook);
void applications_update_background (GtkWidget *window);
void applications_update_itemsize (gint width);
void applications_update_theme (const gchar *themename);
void applications_update_item_layout (gint type);
void add_application (const gchar *filename);
void remove_application (const gchar *filename);
void set_super_folder_visible (void);
gboolean is_super_folder_visible (void);

int applications_start_service (const gchar *service_name,
                                const gchar *method,
                                const gchar* caller_service_name);
								
gboolean launch_application (const char *name, 
                             const char *executable, 
                             const char *argv, 
                             gboolean single_instance, 
                             gboolean startup_notify,
                             const char *caller);
							 
enum 
  {
    LAYOUT_STACK = 0,
    LAYOUT_SIDE  = 1,
    LAYOUT_MAX   = 2
  }t_layout;

enum
  {
	ITEM_NORMAL  = 0,
	ITEM_FOCUSED = 1
  }t_item_status;
  

#define DEFAULT_APPS_PATH PREFIX "/share/applications" 

#endif
